def calculate_aspect(width: int, height: int) -> str:
    def gcd(a, b):
        """En büyük ortak böleni bulan fonksiyon"""
        return a if b == 0 else gcd(b, a % b)

    r = gcd(width, height)
    x = int(width / r)
    y = int(height / r)

    return f"{x}:{y}"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aspect_ratio']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.22.0,<2.0.0']

setup_kwargs = {
    'name': 'aspect-ratio',
    'version': '0.2.0',
    'description': 'Finds the aspect ratio of image',
    'long_description': '# poetry-aspect-ratio\n\n## Property\n1. Calculate aspect ratio from the given height and width.',
    'author': 'M.C.V',
    'author_email': 'murat@visiosoft.com.tr',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mcvarer/poetry-aspect-ratio',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
